@@ -59,7 +59,7 @@ n.locs(ricky)
 ###################################################
 ### code chunk number 9: timelag
 ###################################################
-head(time.lag(leroy, units="mins"))
+head(timeLag(leroy, units="mins"))
 
 
 ###################################################
