@@ -8,12 +8,12 @@ test.measures<-function()
 	checkEquals(distanceSummary(x)$AverDist,mean(d))
 	checkEquals(speed(x),d/t)
 	checkEquals(speedSummary(x)$AverSpeed, mean(d/t))
-	checkEquals(time.lag(x), t)
-	checkEquals(time.lag(x, 'secs'), t)
-	checkEquals(time.lag(x, 'mins'), t/60)
+	checkEquals(timeLag(x), t)
+	checkEquals(timeLag(x, 'secs'), t)
+	checkEquals(timeLag(x, 'mins'), t/60)
 	xx<-moveStack(list(x,x))
 	checkEquals(distance(xx),list(unnamed=d,unnamed1=d))
-	checkEquals(time.lag(xx),list(unnamed=t,unnamed1=t))
+	checkEquals(timeLag(xx),list(unnamed=t,unnamed1=t))
 	checkEquals(speed(xx),list(unnamed=d/t,unnamed1=d/t))
 	proj4string(x)<-'+proj=longlat'
 	checkEquals(distance(x),(dd<-distHaversine( cbind(dx,dx)[-n.locs(x),], cbind(dx,dx)[-1,])))
